@@ -1,15 +1,8 @@
 import re
 from datetime import datetime
 from enum import Enum
-from typing import Dict
-from typing import ItemsView
-from typing import KeysView
-from typing import Optional
-from typing import Union
-from typing import Any
-from typing import ValuesView
-from urllib.parse import quote
-from urllib.parse import unquote
+from typing import Any, Dict, ItemsView, KeysView, Optional, Union, ValuesView
+from urllib.parse import quote, unquote
 
 COOKIE_NAME_VALIDATOR = re.compile(r"[a-z0-9!#$%&'*+.^_`|~\-]+", re.I)
 
@@ -46,7 +39,9 @@ class HttpCookie:
         same_site: Union[bool, HttpCookieSameSitePolicy] = False,
     ):
         if not COOKIE_NAME_VALIDATOR.match(name):
-            raise InvalidHttpCookieNameError(f"Invalid cookie name {name}, cookie name must be valid RFC 2616 token.")
+            raise InvalidHttpCookieNameError(
+                f"Invalid cookie name {name}, cookie name must be valid RFC 2616 token."
+            )
         self._name: str = name
         self.value = value
         self.path = path
@@ -166,7 +161,10 @@ def parse_cookie_header(header: str) -> HttpCookieJar:
             continue
         try:
             result.append(
-                HttpCookie(cookie[0:separator_position].strip(), unquote(cookie[separator_position + 1 :].strip()),)
+                HttpCookie(
+                    cookie[0:separator_position].strip(),
+                    unquote(cookie[separator_position + 1 :].strip()),
+                )
             )
         except HttpCookieError:  # Invalid cookie name
             continue
