@@ -1,30 +1,35 @@
 import copy
 from io import BytesIO
-from typing import Dict
-from typing import Optional
-from typing import Sequence
-from typing import Union
+from typing import Dict, Optional, Sequence, Union
 
 from .http_cookies import HttpCookieJar
 from .http_headers import HttpHeaders
+from .http_parsed_body import HttpParsedBodyTrait
 from .http_status import HttpStatus
 
 
-class HttpResponse:
+class HttpResponse(HttpParsedBodyTrait):
     def __init__(
         self,
         body: Union[bytes, bytearray, str, None] = None,
         status: Union[int, HttpStatus] = HttpStatus.OK,
         encoding: str = "utf-8",
-        headers: Optional[Union[Dict[str, Union[str, Sequence[str]]], HttpHeaders]] = None,
+        headers: Optional[
+            Union[Dict[str, Union[str, Sequence[str]]], HttpHeaders]
+        ] = None,
     ):
-        self._headers = headers if isinstance(headers, HttpHeaders) else HttpHeaders(headers)
+        self._headers = (
+            headers if isinstance(headers, HttpHeaders) else HttpHeaders(headers)
+        )
         if isinstance(status, int):
             status = HttpStatus.from_int(status)
         self.status_code = status
-        self.body: BytesIO = BytesIO()
+        self._body: BytesIO = BytesIO()
         self.encoding = encoding
         self.cookies = HttpCookieJar()
+        self._parsed_body = None
+        self._as_dict = None
+        self._as_str = None
 
         if body:
             self.write(body)
@@ -38,20 +43,33 @@ class HttpResponse:
 
     def write(self, body: Union[str, bytes, bytearray]) -> None:
         if isinstance(body, str):
-            self.body.write(body.encode(self.encoding))
+            self._body.write(body.encode(self.encoding))
         else:
-            self.body.write(body)
+            self._body.write(body)
+
+    @property
+    def body(self) -> BytesIO:
+        return self._body
+
+    @body.setter
+    def body(self, value: Union[str, bytes, bytearray, BytesIO]) -> None:
+        if isinstance(value, BytesIO):
+            self._body = value
+            return
+
+        self._body = BytesIO()
+        self.write(value)
 
     @property
     def writable(self) -> bool:
-        return not self.body.closed
+        return not self._body.closed
 
     def close(self) -> None:
-        self.body.close()
+        self._body.close()
 
     def __str__(self) -> str:
-        self.body.seek(0)
-        return self.body.read().decode(self.encoding)
+        self._body.seek(0)
+        return self._body.read().decode(self.encoding)
 
     def __eq__(self, other) -> bool:
         if not isinstance(other, HttpResponse):
