@@ -1,7 +1,5 @@
 from io import BytesIO
-from typing import Any
-from typing import Callable
-from typing import Dict
+from typing import Any, Callable, Dict
 
 from .application import Application
 from .http_error import HttpError
@@ -50,7 +48,8 @@ def create_wsgi_handler(
                 response = HttpResponse("Internal Server Error", 500)
 
         start(
-            str(int(response.status_code)), [(key, value) for key, value in response.headers.items()],
+            str(int(response.status_code)),
+            [(key, value) for key, value in response.headers.items()],
         )
 
         response.body.seek(0)
@@ -59,7 +58,9 @@ def create_wsgi_handler(
     return _handler
 
 
-def serve(application: Application, host: str = "127.0.0.1", port=80, debug: bool = False) -> None:
+def serve(
+    application: Application, host: str = "127.0.0.1", port=80, debug: bool = False
+) -> None:
     import bjoern
 
     wsgi_handler = create_wsgi_handler(application, debug=debug)
